Certificados | OiRA
Description: Dependiendo del enfoque adoptado por el desarrollador/socio nacional de la herramienta OiRA, es posible que se pueda obtener un certificado de su evaluación de riesgos. Si desea información detallada sobre las ventajas de dichos certificados, póngase en contacto con su socio nacional de OiRA.

Temas

# Certificados

Dependiendo del enfoque adoptado por el desarrollador/socio nacional de la herramienta OiRA, es posible que se pueda obtener un certificado de su evaluación de riesgos. Si desea información detallada sobre las ventajas de dichos certificados, póngase en contacto con su socio nacional de OiRA.

Cómo obtener un certificado

## Realizar una evaluación de riesgos completa

A medida que realiza su evaluación de riesgos, OiRA registrará sus avances. Una vez evaluado un reducido porcentaje de riesgos, la herramienta le informa de la posibilidad de obtener un certificado una vez que haya finalizado la evaluación de riesgos completa. Cada socio/desarrollador nacional de la herramienta OiRA establece el umbral de cómo se define una evaluación de riesgos «completa». El certificado está disponible a través del botón «Grado de cumplimentación» en el menú de la izquierda.

Pantalla con el aviso sobre el certificado

## Vea y publique su certificado

Cuando haga clic en el botón «Ver certificado», se le pedirá que introduzca el nombre de su empresa que debe aparecer en el certificado. Dependiendo de la configuración nacional, es posible que se le pida que introduzca más datos para asegurar que el certificado incluye toda la información que debe facilitar.

Si marca la casilla «Publicar», se le mostrará un enlace único (URL) a su certificado. Copie este enlace y compártalo con quienes puedan estar interesados, como prueba de que ha llevado usted a cabo su evaluación de riesgos.

Publicar el certificado

Nota: Solo se harán públicos los datos que aparecen en esa página. Este enlace no está disponible a través del menú de ningún sitio web, etc. Es específicamente suyo. Sin embargo, teóricamente cualquier persona que navegue por Internet podría ver el certificado que ha subido.

El certificado solo indica que ha respondido a un determinado porcentaje de riesgos en la herramienta de evaluación de riesgos, pero no facilita ninguna otra información. Solo usted, y nadie más, podrá ver las respuestas específicas a la evaluación de riesgos que se dan al completar la herramienta OiRA.

Scroll to top Load toolbar…
Back

## 5-certificates.md

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More